summaryrefslogtreecommitdiffstats
path: root/kreversi/kreversi.cpp
diff options
context:
space:
mode:
authorTimothy Pearson <kb9vqf@pearsoncomputing.net>2011-12-16 09:58:53 -0600
committerTimothy Pearson <kb9vqf@pearsoncomputing.net>2011-12-16 09:58:53 -0600
commit84ace1135cac57993b72fee7105b92def1638d32 (patch)
treeb8871eb76e3db4a062731b0ce7c99c24fac119e8 /kreversi/kreversi.cpp
parent97d1732e257f8700488d7ca1660ae7eba8fc6065 (diff)
downloadtdegames-84ace1135cac57993b72fee7105b92def1638d32.tar.gz
tdegames-84ace1135cac57993b72fee7105b92def1638d32.zip
Revert "Rename a number of old tq methods that are no longer tq specific"
This reverts commit 97d1732e257f8700488d7ca1660ae7eba8fc6065.
Diffstat (limited to 'kreversi/kreversi.cpp')
-rw-r--r--kreversi/kreversi.cpp12
1 files changed, 6 insertions, 6 deletions
diff --git a/kreversi/kreversi.cpp b/kreversi/kreversi.cpp
index 60d555f3..4c72251b 100644
--- a/kreversi/kreversi.cpp
+++ b/kreversi/kreversi.cpp
@@ -39,7 +39,7 @@
#include <unistd.h>
-#include <layout.h>
+#include <tqlayout.h>
#include <tqlabel.h>
#include <tqlistbox.h>
@@ -329,9 +329,9 @@ void KReversi::slotUndo()
}
if (m_game->toMove() == computerColor()) {
// Must repaint so that the new move is not shown before the old
// one is removed on the screen.
- m_gameView->repaint();
+ m_gameView->tqrepaint();
computerMakeMove();
}
else
@@ -609,21 +609,21 @@ void KReversi::showGameOver(Color color)
if ( color == Nobody ) {
KNotifyClient::event(winId(), "draw", i18n("Draw!"));
TQString s = i18n("Game is drawn!\n\nYou : %1\nComputer: %2")
- .arg(human).arg(computer);
+ .tqarg(human).tqarg(computer);
KMessageBox::information(this, s, i18n("Game Ended"));
score.setType(KExtHighscore::Draw);
}
else if ( humanColor() == color ) {
KNotifyClient::event(winId(), "won", i18n("Game won!"));
TQString s = i18n("Congratulations, you have won!\n\nYou : %1\nComputer: %2")
- .arg(human).arg(computer);
+ .tqarg(human).tqarg(computer);
KMessageBox::information(this, s, i18n("Game Ended"));
score.setType(KExtHighscore::Won);
}
else {
KNotifyClient::event(winId(), "lost", i18n("Game lost!"));
TQString s = i18n("You have lost the game!\n\nYou : %1\nComputer: %2")
- .arg(human).arg(computer);
+ .tqarg(human).tqarg(computer);
KMessageBox::information(this, s, i18n("Game Ended"));
score.setType(KExtHighscore::Lost);
}
@@ -329,9 +329,9 @@ void KReversi::slotUndo()
}
if (m_game->toMove() == computerColor()) {
- // Must repaint so that the new move is not shown before the old
+ // Must tqrepaint so that the new move is not shown before the old
// one is removed on the screen.